@@ -1530,11 +1530,11 @@ int vimos_science_impl(cpl_frameset *frameset, cpl_parameterlist *parlist,
     //TODO: Place this in a better place. The whole recipe needs refactoring...
     cpl_image        * mapped_flat_sed = NULL;
     cpl_propertylist * flat_sed_header = NULL;
+    vimos::detected_slits det_slits = 
+            vimos::detected_slits_from_tables(slits, polytraces, nx);
+    mosca::wavelength_calibration wave_cal(idscoeff, reference);
     if(photcal_apply_flat_corr || response_apply_flat_corr)
     {
-        vimos::detected_slits det_slits = 
-                vimos::detected_slits_from_tables(slits, polytraces, nx);
-        mosca::wavelength_calibration wave_cal(idscoeff, reference);
         const cpl_frame * flat_sed_frame = 
                 cpl_frameset_find_const(frameset, flat_sed_tag);
         const char * filename = cpl_frame_get_filename(flat_sed_frame);
@@ -1646,7 +1646,8 @@ int vimos_science_impl(cpl_frameset *frameset, cpl_parameterlist *parlist,
                                                  resp_fit_nknots,
                                                  resp_fit_degree,
                                                  response_interp,
-                                                 flat_sed_norm_factor);
+                                                 flat_sed_norm_factor,
+                                                 det_slits);
 
                 cpl_table_delete(ext_table);
                 cpl_table_delete(flux_table);
@@ -1775,7 +1776,8 @@ int vimos_science_impl(cpl_frameset *frameset, cpl_parameterlist *parlist,
                 {
                     cpl_msg_info(cpl_func, "Applying flat SED correction");
                     vimos_science_correct_flat_sed(science_images, slits, 
-                            mapped_flat_sed, flat_sed_header, specphot_header);
+                            mapped_flat_sed, flat_sed_header, specphot_header,
+                            det_slits);
                 }
                 
                 calibrated = mos_apply_photometry(science_images, response_interp,
@@ -1842,9 +1844,11 @@ int vimos_science_impl(cpl_frameset *frameset, cpl_parameterlist *parlist,
                 {
                     //We assume that the mapped flat profile has no associated error
                     vimos_science_correct_flat_sed(science_images, slits, 
-                            mapped_flat_sed, flat_sed_header, specphot_header);
+                            mapped_flat_sed, flat_sed_header, specphot_header,
+                            det_slits);
                     vimos_science_correct_flat_sed(science_images_err, slits, 
-                            mapped_flat_sed, flat_sed_header, specphot_header);
+                            mapped_flat_sed, flat_sed_header, specphot_header,
+                            det_slits);
                 }
 
                 calibrated = mos_propagate_photometry_error(science_images, 
@@ -1945,7 +1949,8 @@ int vimos_science_impl(cpl_frameset *frameset, cpl_parameterlist *parlist,
             {
                 cpl_msg_info(cpl_func, "Applying flat SED correction");
                 vimos_science_correct_flat_sed_mapped(mapped_images, slits, 
-                        mapped_flat_sed, flat_sed_header, specphot_header);
+                        mapped_flat_sed, flat_sed_header, specphot_header,
+                        det_slits);
             }
            
             calibrated = mos_apply_photometry(mapped_images, response_interp,
